@@ -1,3 +1,5 @@
+import asyncio
+from asyncio.base_events import BaseEventLoop
 import threading
 from typing import List
 from google.protobuf.descriptor import Descriptor, FieldDescriptor, FileDescriptor, MethodDescriptor, ServiceDescriptor
@@ -74,10 +76,15 @@ async def process_grpc_request(descriptor: FileDescriptor, service_name: str, me
 
 
 async def http_exception(request, exc):
-  if 'favicon.ico' not in str(request.url):
+  if 'favicon.ico' in str(request.url):
+    detail = 'not found'
+    status_code = 404
+  else:
     path = urlparse(str(request.url)).path
     logging.error(f'[{exc.status_code}] {request.method} {path} - {exc.detail}')
-  return JSONResponse({'detail': exc.detail, 'status': exc.status_code}, status_code=exc.status_code)
+    detail = exc.detail
+    status_code = exc.status_code
+  return JSONResponse({'detail': detail, 'status': exc.status_code}, status_code=status_code)
 
 
 def get_http_handlers(descriptor: FileDescriptor, service_name: str, method: str, channel: Channel):
@@ -112,7 +119,8 @@ def get_http_handlers(descriptor: FileDescriptor, service_name: str, method: str
   return method_get_handler, request_handler
 
 
-def start_gateway(descriptor: FileDescriptor, port: int = 7070):
+def start_gateway(descriptor: FileDescriptor, loop: BaseEventLoop, port: int = 7070):
+  logging.info('starting gateway...')
   reset_cached_client('localhost:8080')
   debug = 'DELPHAI_ENVIRONMENT' in os.environ and os.environ['DELPHAI_ENVIRONMENT'] == 'development'
   app = Starlette(debug=debug, exception_handlers={HTTPException: http_exception})
@@ -145,4 +153,5 @@ def start_gateway(descriptor: FileDescriptor, port: int = 7070):
               http_path = getattr(http_rule, supported_method)
               if http_path != '':
                 app.add_route(http_path, route=request_handler, methods=[supported_method])
-  return serve(app, config)
\ No newline at end of file
+  loop.create_task(serve(app, config))
+  logging.info(f'started gateway on port {port}')
\ No newline at end of file
