@@ -1,3 +1,6 @@
+import asyncio
+from asyncio.base_events import BaseEventLoop
+from grpc import Server
 from grpc.experimental import aio
 from grpc_reflection.v1alpha import reflection
 from grpc_health.v1 import health, health_pb2_grpc
@@ -22,8 +25,8 @@ def create_grpc_server(descriptor: FileDescriptor):
   return server
 
 
-async def start_server(server):
+def start_server(server: Server, loop: BaseEventLoop):
   logging.info('starting grpc server...')
-  await server.start()
-  logging.info('started grpc server on port 8080')
-  await server.wait_for_termination()
\ No newline at end of file
+  loop.run_until_complete(server.start())
+  loop.create_task(server.wait_for_termination())
+  logging.info('started grpc server on port 8080')
\ No newline at end of file
